You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@commons.apache.org by di...@apache.org on 2006/04/27 15:44:14 UTC

svn commit: r397542 - /jakarta/commons/proper/jexl/trunk/src/java/org/apache/commons/jexl/resolver/FlatResolver.java

Author: dion
Date: Thu Apr 27 06:43:47 2006
New Revision: 397542

URL: http://svn.apache.org/viewcvs?rev=397542&view=rev
Log:
More checkstyle

Modified:
    jakarta/commons/proper/jexl/trunk/src/java/org/apache/commons/jexl/resolver/FlatResolver.java

Modified: jakarta/commons/proper/jexl/trunk/src/java/org/apache/commons/jexl/resolver/FlatResolver.java
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/jexl/trunk/src/java/org/apache/commons/jexl/resolver/FlatResolver.java?rev=397542&r1=397541&r2=397542&view=diff
==============================================================================
--- jakarta/commons/proper/jexl/trunk/src/java/org/apache/commons/jexl/resolver/FlatResolver.java (original)
+++ jakarta/commons/proper/jexl/trunk/src/java/org/apache/commons/jexl/resolver/FlatResolver.java Thu Apr 27 06:43:47 2006
@@ -1,3 +1,18 @@
+/*
+ * Copyright 2002-2006 The Apache Software Foundation.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 package org.apache.commons.jexl.resolver;
 
 import org.apache.commons.jexl.JexlExprResolver;
@@ -32,10 +47,10 @@
      *  CTOR that lets you override the default behavior of
      *  noValOnNull, which is true. (jexl gets a shot after if null)
      *
      *  @param noValOnNull Whether NO_VALUE will be returned instead of null.
      */
-    public FlatResolver(boolean noValOnNull) {
-        this.noValOnNull = noValOnNull;
+    public FlatResolver(boolean valOnNull) {
+        noValOnNull = valOnNull;
     }
 
     /**



---------------------------------------------------------------------
@@ -32,10 +47,10 @@
      *  noValOnNull, which is true. (jexl gets a shot after if null)
      *
-     *  @param noValOnNull Whether NO_VALUE will be returned instead of null.
+     *  @param valOnNull Whether NO_VALUE will be returned instead of null.
      */
To unsubscribe, e-mail: commons-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: commons-dev-help@jakarta.apache.org